# Helper for Maxi

All the Functions I could need multiple times

## Instructions

1. Install:

```sh
pip install helper-for-maxi
```

2. Import package:

```py
import maximyoga
import maximyoga.*
from maximyoga import *
from maximyoga.* import *
# You can replace * with what you need!
```